from setuptools import setup, find_packages

setup(
    name='pydemolib',
    version='0.1.0',
    packages=find_packages(),
    install_requires=[],
    author='Dinesh',
    author_email='dineshsutharinfo@gmail.com',
    description='A simple example library',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/dineshsuthar03/pydemolib',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)
